/* $Id: dbz.h,v 1.1.1.1 1998/07/29 15:14:28 proff Exp $
 * $Copyright$
 */

#ifndef DBZ_H
#define DBZ_H

#include "../config.h"

/* for dbm and dbz */
typedef struct
{
	char *dptr;
	int dsize;
} datum;


/*
 * In principle we could handle unlimited-length keys by operating a chunk
 * at a time, but it's not worth it in practice.  Setting a nice large
 * bound on them simplifies the code and doesn't hurt anything.
 */
#define DBZMAXKEY	255

#include "dbz.ext"

#endif /* DBZ_H */
